@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1101';
+our $VERSION = '0.1102';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -53,6 +53,10 @@ sub parse {
     die 'No chord to parse'
         unless $chord;
 
+    my $note_re  = qr/[A-G][#b]?[#b]?/;
+    my $upper_re = qr/^[A-Z]+$/;
+    my $lower_re = qr/^[a-z]+$/;
+
     # Literal diatonic modes when chords attribute is zero
     my @roman = qw( I ii iii IV V vi vii ); # Default to major/ionian
     if ( $self->scale_name eq 'dorian' ) {
@@ -101,7 +105,7 @@ sub parse {
     $chord =~ s/dim/o/;
 
     # Get just the note part of the chord name
-    ( my $note = $chord ) =~ s/^([A-G][#b]?[#b]?).*$/$1/;
+    ( my $note = $chord ) =~ s/^($note_re).*$/$1/;
 
     # Get the roman representation based on the scale position
     my $position = first_index { $_ eq $note } @notes;
@@ -114,7 +118,7 @@ sub parse {
     my $roman = $roman[$position];
 
     # Get everything but the note part
-    ( my $decorator = $chord ) =~ s/^(?:[A-G][#b]?[#b]?)(.*)$/$1/;
+    ( my $decorator = $chord ) =~ s/^(?:$note_re)(.*)$/$1/;
 
     # Are we minor or diminished?
     my $minor = $decorator =~ /[mo]/ ? 1 : 0;
@@ -138,59 +142,49 @@ sub parse {
     print "ROMAN: $roman, DECO: $decorator\n" if $self->verbose;
 
     # A remaining note name is a bass decorator
-    if ( $decorator =~ /([A-G][#b]?[#b]?)/ ) {
+    if ( $decorator =~ /($note_re)/ ) {
         my $name = $1;
         $position = first_index { $_ eq $name } @notes;
         print "NOTE: $name, POSN: $position\n" if $self->verbose;
         if ( $position >= 0 ) {
-            $decorator =~ s/[A-G][#b]?[#b]?/$roman[$position]/;
+            $decorator =~ s/$note_re/$roman[$position]/;
         }
         else {
             ( $position, $accidental ) = _pos_acc( $name, $position, \@notes );
             print "POSN: $position, ACCI: $accidental\n" if $self->verbose;
             my $bass = $accidental . $roman[$position];
-            $decorator =~ s/[A-G][#b]?[#b]?/$bass/;
+            $decorator =~ s/$note_re/$bass/;
 
             # Handle these unfortunate edge cases
-            if ( $decorator =~ /#I\b/i && $roman[1] =~ /^[A-Z]+$/ ) {
-                $decorator =~ s/#I\b/bII/;
-                $decorator =~ s/#i\b/bII/;
+            if ( $decorator =~ /#I\b/i && $roman[1] =~ /$upper_re/ ) {
+                $decorator =~ s/#I\b/bII/i;
             }
-            elsif ( $decorator =~ /#I\b/i && $roman[1] =~ /^[a-z]+$/ ) {
-                $decorator =~ s/#I\b/bii/;
-                $decorator =~ s/#i\b/bii/;
+            elsif ( $decorator =~ /#I\b/i && $roman[1] =~ /$lower_re/ ) {
+                $decorator =~ s/#I\b/bii/i;
             }
-            elsif ( $decorator =~ /#II\b/i && $roman[2] =~ /^[A-Z]+$/ ) {
-                $decorator =~ s/#II\b/bIII/;
-                $decorator =~ s/#ii\b/bIII/;
+            elsif ( $decorator =~ /#II\b/i && $roman[2] =~ /$upper_re/ ) {
+                $decorator =~ s/#II\b/bIII/i;
             }
-            elsif ( $decorator =~ /#II\b/i && $roman[2] =~ /^[a-z]+$/ ) {
-                $decorator =~ s/#II\b/biii/;
-                $decorator =~ s/#ii\b/biii/;
+            elsif ( $decorator =~ /#II\b/i && $roman[2] =~ /$lower_re/ ) {
+                $decorator =~ s/#II\b/biii/i;
             }
-            elsif ( $decorator =~ /#IV\b/i && $roman[4] =~ /^[A-Z]+$/ ) {
-                $decorator =~ s/#IV\b/bV/;
-                $decorator =~ s/#iv\b/bV/;
+            elsif ( $decorator =~ /#IV\b/i && $roman[4] =~ /$upper_re/ ) {
+                $decorator =~ s/#IV\b/bV/i;
             }
-            elsif ( $decorator =~ /#IV\b/i && $roman[4] =~ /^[a-z]+$/ ) {
-                $decorator =~ s/#IV\b/bv/;
-                $decorator =~ s/#iv\b/bv/;
+            elsif ( $decorator =~ /#IV\b/i && $roman[4] =~ /$lower_re/ ) {
+                $decorator =~ s/#IV\b/bv/i;
             }
-            elsif ( $decorator =~ /#V\b/i && $roman[5] =~ /^[A-Z]+$/ ) {
-                $decorator =~ s/#V\b/bVI/;
-                $decorator =~ s/#v\b/bVI/;
+            elsif ( $decorator =~ /#V\b/i && $roman[5] =~ /$upper_re/ ) {
+                $decorator =~ s/#V\b/bVI/i;
             }
-            elsif ( $decorator =~ /#V\b/i && $roman[5] =~ /^[a-z]+$/ ) {
-                $decorator =~ s/#V\b/bvi/;
-                $decorator =~ s/#v\b/bvi/;
+            elsif ( $decorator =~ /#V\b/i && $roman[5] =~ /$lower_re/ ) {
+                $decorator =~ s/#V\b/bvi/i;
             }
-            elsif ( $decorator =~ /#VI\b/i && $roman[6] =~ /^[A-Z]+$/ ) {
-                $decorator =~ s/#VI\b/bVII/;
-                $decorator =~ s/#vi\b/bVII/;
+            elsif ( $decorator =~ /#VI\b/i && $roman[6] =~ /$upper_re/ ) {
+                $decorator =~ s/#VI\b/bVII/i;
             }
-            elsif ( $decorator =~ /#VI\b/i && $roman[6] =~ /^[a-z]+$/ ) {
-                $decorator =~ s/#VI\b/bvii/;
-                $decorator =~ s/#vi\b/bvii/;
+            elsif ( $decorator =~ /#VI\b/i && $roman[6] =~ /$lower_re/ ) {
+                $decorator =~ s/#VI\b/bvii/i;
             }
         }
     }
@@ -284,7 +278,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1101
+version 0.1102
 
 =head1 SYNOPSIS
 
